@@ -1,15 +1,6 @@
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#    http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
-# implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# This file is dual licensed under the terms of the Apache License, Version
+# 2.0, and the BSD License. See the LICENSE file in the root of this repository
+# for complete details.
 
 from __future__ import absolute_import, division, print_function
 
@@ -18,6 +9,7 @@ import os
 
 import pytest
 
+from cryptography.hazmat.backends.interfaces import CipherBackend
 from cryptography.hazmat.primitives.ciphers import algorithms, modes
 
 from .utils import generate_encrypt_test
@@ -32,8 +24,8 @@ from ...utils import (
     ),
     skip_message="Does not support Camellia ECB",
 )
-@pytest.mark.cipher
-class TestCamellia_ECB(object):
+@pytest.mark.requires_backend_interface(interface=CipherBackend)
+class TestCamelliaModeECB(object):
     test_ECB = generate_encrypt_test(
         load_cryptrec_vectors,
         os.path.join("ciphers", "Camellia"),
@@ -53,8 +45,8 @@ class TestCamellia_ECB(object):
     ),
     skip_message="Does not support Camellia CBC",
 )
-@pytest.mark.cipher
-class TestCamellia_CBC(object):
+@pytest.mark.requires_backend_interface(interface=CipherBackend)
+class TestCamelliaModeCBC(object):
     test_CBC = generate_encrypt_test(
         load_nist_vectors,
         os.path.join("ciphers", "Camellia"),
@@ -70,8 +62,8 @@ class TestCamellia_CBC(object):
     ),
     skip_message="Does not support Camellia OFB",
 )
-@pytest.mark.cipher
-class TestCamellia_OFB(object):
+@pytest.mark.requires_backend_interface(interface=CipherBackend)
+class TestCamelliaModeOFB(object):
     test_OFB = generate_encrypt_test(
         load_nist_vectors,
         os.path.join("ciphers", "Camellia"),
@@ -87,8 +79,8 @@ class TestCamellia_OFB(object):
     ),
     skip_message="Does not support Camellia CFB",
 )
-@pytest.mark.cipher
-class TestCamellia_CFB(object):
+@pytest.mark.requires_backend_interface(interface=CipherBackend)
+class TestCamelliaModeCFB(object):
     test_CFB = generate_encrypt_test(
         load_nist_vectors,
         os.path.join("ciphers", "Camellia"),
